@@ -100,12 +100,27 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
         prompt_local_time_timezone_split_len = len(prompt_local_time_timezone_split)
         if prompt_local_time_timezone_split_len == 3:
             Prompt_Local_Time_list.append(prompt_local_time_timezone_split[0] + " " + prompt_local_time_timezone_split[1])
+        elif prompt_local_time_timezone_split_len == 6:
+            b = [1, 2, 3, 5]
+            subset_time = [prompt_local_time_timezone_split[i] for i in b]
+            Prompt_Local_Time_list.append(" ".join(subset_time))
         else:
             print("Prompt response time zone error : " + intermediate_participant_path + "//" + date_in_study)
             Prompt_Local_Time_list.append(prompt_local_time_timezone)
+            raise Exception("Unable to parse Actual_Prompt_Local_Time")
+
+    prompt_local_time_timezone = df_reprompt['Actual_Prompt_Local_Time'][0]
+    prompt_local_time_timezone_split = prompt_local_time_timezone.split(" ")
+    prompt_local_time_timezone_split_len = len(prompt_local_time_timezone_split)
+    if prompt_local_time_timezone_split_len == 3:
+        converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
+        prompt_dateobject_column = list(map(converter, Prompt_Local_Time_list))
+    elif prompt_local_time_timezone_split_len == 6:
+        converter = lambda x: datetime.strptime(x, "%b %d %H:%M:%S %Y")
+        prompt_dateobject_column = list(map(converter, Prompt_Local_Time_list))
+    else:
+        raise Exception("Unable to parse Actual_Prompt_Local_Time")
 
-    converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
-    prompt_dateobject_column = list(map(converter, Prompt_Local_Time_list))
     df_reprompt['Actual_Prompt_Local_DateTime'] = prompt_dateobject_column
 
     return df_reprompt
